#
# spec file for package XyGrib
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2018 Dr. Axel Braun
# Copyright (c) 2018 Dominig ar Foll (Intel Open Source)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           XyGrib
Version:        1.2.4
Release:        1.2
Summary:        A weather visualization package
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://opengribs.org/en/
Source0:        https://github.com/opengribs/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}.desktop
BuildRequires:  cmake
BuildRequires:  libnova-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} < 1500
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif

%description
XyGrib is a weather visualization package that interacts with
OpenGribs's Grib server providing a choice of global and large area
atmospheric and wave models.

XyGrib also uses pre-cut Gribs of high-resolution regional models
found on OpenSkiron.org.

%prep
%setup -q
cp %{S:1} %{S:2} .

%build
# -DNO_UPDATE=1 deactivates XyGrib internal SW update
# -DOPENSUSE=1  macro for optional openSUSE friendly options in the source code
%cmake \
    -DCMAKE_INSTALL_PREFIX=%{_datadir} \
	-DCMAKE_CXX_FLAGS="%{optflags} -DNO_UPDATE=1 -DOPENSUSE=1"
%make_jobs

%install
%cmake_install

# xygrib Makefile install is not very Linux
mkdir %{buildroot}/%{_bindir}
mv %{buildroot}/%{_datadir}/XyGrib/XyGrib %{buildroot}/%{_bindir}/XyGrib

# Uses handmade xygrib.desktop file from OSB
%suse_update_desktop_file -i %{name}

# Starting with openSUSE 15.0 this is automatic
%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/XyGrib.desktop
%{_datadir}/pixmaps/XyGrib.png

%changelog
* Thu Feb 21 2019 Jan Engelhardt <jengelh@inai.de>
- Remove marketing from descriptions.
* Thu Feb 21 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 1.2.4
- New feature - Arome 0.025 deg regional model added
- Grib grid only shown if there is weather display selected and z
  zoom factor allows it (no more black out)
- Many code improvements thanks to Didier
- Bug fixes including crashes on closing POI Editor or opening MeteoTable
* Wed Jan  9 2019 Axel Braun <axel.braun@gmx.de>
- version 1.2.2
- New feature - Gust color map
- Cloud display problems with ICON gribs is fixed.
- Enforcement of minimum area for grib requests is fixed.
- “Bad Request” errors are no longer returned on very small area requests.
- Several other bugs were fixed and several code stability improvements were included.
* Wed Dec 19 2018 Martin Pluskal <mpluskal@suse.com>
- Merge packaging changes from Dominig ar Foll
- Update to version 1.2.0
* Wed Jul 25 2018 mpluskal@suse.com
- Update to version 1.1.0
- Update build system and dependencies
* Wed May 30 2018 axel.braun@gmx.de
- Version 1.0.1
  Initial build on OBS
  Copyright added to spec file
  Changes originated in zyGrib:
* Thu Mar  8 2018 mpluskal@suse.com
- Use gcc7 for Leap
- Clean up spec file using spec-cleaner
* Sun Feb 12 2017 mpluskal@suse.com
- Cleanup spec file:
  * Use spec-cleaner
  * Drop codelite builddependency which prevented buildning on SLE
  * Force optflags on all targets
* Fri Dec  9 2016 axel.braun@gmx.de
- Version 8.0.1
  * Bug fixed: inverted sea current arrows
  * There was a problem with some dll in the Windows archive of the previous version.
  * Read GRIB 2 files.
  * Bug fixed: inverted sea current arrows.
  * Display equivalent potential temperature théta-e at the surface and in altitude (calculated from the temperature, pressure and moisture if it is not present in the file).
  * Faster calculation of the level lines.
  * Ability to interrupt before the opening of a large file.
  * Use QT version 5.
  * Use g2clib NOAA's g2clib library for decoding the GRIB2 format.
* Tue Nov 11 2014 axel.braun@gmx.de
- Version 6.2.4
- Source patch for qmake
* Sun Dec  1 2013 axel.braun@gmx.de
- New version 6.2.1
  x-------------------------------------------------------------------
* Sat Nov 16 2013 axel.braun@gmx.de
- Version 6.2.0, dependency on qwt removed
* Wed Oct 30 2013 axel.braun@gmx.de
- Version 6.1.4
* Tue Apr 23 2013 axel.braun@gmx.de
- version 6.1.3
* Thu Aug 16 2012 axel.braun@gmx.de
- release 6.0.0
- changes to spec file for Fedora/RHEL build
* Wed Dec 21 2011 idonmez@suse.com
- Fix license
* Wed Dec 21 2011 axel.braun@gmx.de
- release 5.1.0
* Thu Sep 22 2011 axel.braun@gmx.de
- release 5.0.6
* Sun Aug 14 2011 axel.braun@gmx.de
- Initial build.
  Thu Apr 01 2010
- Original Spec Build by "Brian K. White" <brian@aljex.com>
